@@ -241,9 +241,10 @@ class Protobuf:
             Text('"', ColorConfig.default.value),
             Text(";", ColorConfig.default.value),
         ]
-
-        syntax_string = self.make_string(line, 0, self.syntax.comments, self.config.SPACES_BETWEEN_VALUE_COMMENT,
-                                         color_text_list)
+        syntax_string, bottom_comment_text_list = self.make_string(line, 0, self.syntax.comments,
+                                                                   self.config.SPACES_BETWEEN_VALUE_COMMENT,
+                                                                   color_text_list)
+        self.text_list.extend(bottom_comment_text_list)
         self.text_list.append(Text("\n", ColorConfig.default.value))
         return syntax_string
 
@@ -259,8 +260,10 @@ class Protobuf:
             Text(";", ColorConfig.default.value)
         ]
 
-        package_string = self.make_string(line, 0, self.package.comments, self.config.SPACES_BETWEEN_VALUE_COMMENT,
-                                          color_text_list)
+        package_string, bottom_comment_text_list = self.make_string(line, 0, self.package.comments,
+                                                                    self.config.SPACES_BETWEEN_VALUE_COMMENT,
+                                                                    color_text_list)
+        self.text_list.extend(bottom_comment_text_list)
         self.text_list.append(Text("\n", ColorConfig.default.value))
         return package_string
 
@@ -321,7 +324,10 @@ class Protobuf:
 
         space_between_number_comment = max_length - len(line) + self.config.SPACES_BETWEEN_VALUE_COMMENT
 
-        return self.make_string(line, 0, option.comments, space_between_number_comment, color_text_list)
+        string, bottom_comment_text_list = self.make_string(line, 0, option.comments, space_between_number_comment,
+                                                            color_text_list)
+        self.text_list.extend(bottom_comment_text_list)
+        return string
 
     def imports_string(self):
         if not self.imports:
@@ -359,7 +365,10 @@ class Protobuf:
         ]
         space_between_number_comment = max_length - len(line) + self.config.SPACES_BETWEEN_VALUE_COMMENT
 
-        return self.make_string(line, 0, import_obj.comments, space_between_number_comment, color_text_list)
+        string, bottom_comment_text_list = self.make_string(line, 0, import_obj.comments, space_between_number_comment,
+                                                            color_text_list)
+        self.text_list.extend(bottom_comment_text_list)
+        return string
 
     def create_object_header(self, obj, indents, no_comment, max_length):
         line = f'{obj.key} {obj.name} ' + "{"
@@ -380,7 +389,10 @@ class Protobuf:
             return self.make_indented_line(line, indents=indents)
         else:
             comments = [comment for comment in obj.comments if comment.position is not Position.BOTTOM]
-            return self.make_string(line, indents, comments, space_between_number_comment, color_text_list)
+            header, bottom_comment_text_list = self.make_string(line, indents, comments, space_between_number_comment,
+                                                                color_text_list)
+            self.text_list.extend(bottom_comment_text_list)
+            return header
 
     def create_object_rear(self, obj, indents):
         bottom_comments = [comment for comment in obj.comments if comment.position == Position.BOTTOM]
@@ -388,10 +400,19 @@ class Protobuf:
             Text(self.config.ONE_SPACE * indents, ColorConfig.default.value),
             Text("}", ColorConfig.default.value)
         ]
+        rear, bottom_comment_text_list = self.make_string('}', indents, bottom_comments,
+                                                          self.config.SPACES_BETWEEN_VALUE_COMMENT,
+                                                          color_text_list)
+        self.text_list.extend(bottom_comment_text_list)
+        # all objects(message, service etc.) are in the first level, no any nested inner objects, add new line for all
+        # of them.
+        if self.config.flatten and not isinstance(obj, Oneof):
+            self.text_list.append(Text("\n", ColorConfig.default.value))
+        else:
+            # not parent id, add new line
+            if not obj.parent_id:
+                self.text_list.append(Text("\n", ColorConfig.default.value))
 
-        rear = self.make_string('}', indents, bottom_comments, self.config.SPACES_BETWEEN_VALUE_COMMENT,
-                                color_text_list)
-        self.text_list.append(Text("\n", ColorConfig.default.value))
         return rear
 
     @staticmethod
@@ -542,8 +563,11 @@ class Protobuf:
         if no_comment:
             return self.make_indented_line(line, indents)
         else:
-            return self.make_string(line, indents, message_element.comments, space_between_number_comment,
-                                    color_text_list)
+            string, bottom_comment_text_list = self.make_string(line, indents, message_element.comments,
+                                                                space_between_number_comment,
+                                                                color_text_list)
+            self.text_list.extend(bottom_comment_text_list)
+            return string
 
     def extend_element_string(
             self,
@@ -592,7 +616,10 @@ class Protobuf:
         if no_comment:
             return self.make_indented_line(line, indents=indents)
         else:
-            return self.make_string(line, indents, enum_element.comments, space_between_number_comment, color_text_list)
+            element_string, bottom_comment_text_list = self.make_string(line, indents, enum_element.comments,
+                                                                        space_between_number_comment, color_text_list)
+            self.text_list.extend(bottom_comment_text_list)
+            return element_string
 
     def service_element_string(
             self,
@@ -603,7 +630,6 @@ class Protobuf:
             space_between_equal_sign_number,
             space_between_number_comment
     ):
-        # rpc SeatAvailability (SeatAvailabilityRequest) returns (SeatAvailabilityResponse);
         line = f'{service_element.label} {service_element.name} ({service_element.request}) returns ({service_element.response});'
         color_text_list = [
             Text(self.config.ONE_SPACE * indents, ColorConfig.default.value),
@@ -626,8 +652,11 @@ class Protobuf:
         if no_comment:
             return self.make_indented_line(line, indents=indents)
         else:
-            return self.make_string(line, indents, service_element.comments, space_between_number_comment,
-                                    color_text_list)
+            string, bottom_comment_text_list = self.make_string(line, indents, service_element.comments,
+                                                                space_between_number_comment,
+                                                                color_text_list)
+            self.text_list.extend(bottom_comment_text_list)
+            return string
 
     def make_string(self, value_line, indents, comments, space_between_number_comment, color_text_list):
         if self.config.top_comment:
@@ -646,11 +675,12 @@ class Protobuf:
             color_text_list = comment_text_list + color_text_list
 
         indented_bottom_comment_lines = []
+        bottom_comment_text_list = []
         if bottom_comment_lines:
             comment_results = self.to_comment_lines_with_comment_slash(bottom_comment_lines, indents)
             indented_bottom_comment_lines = comment_results["indented_comment_lines"]
-            comment_text_list = comment_results["comment_text_list"]
-            color_text_list = comment_text_list + color_text_list
+            bottom_comment_text_list = comment_results["comment_text_list"]
+            # color_text_list = color_text_list + comment_text_list
 
         lines = indented_top_comment_lines
         if right_comment:
@@ -667,9 +697,7 @@ class Protobuf:
             self.text_list.extend(color_text_list)
         else:
             lines.append(value_line)
-            # color_text_list.insert(0, Text(self.config.ONE_SPACE * indents, ColorConfig.default.value))
             color_text_list.append(Text("\n", ColorConfig.default.value))
-
             self.text_list.extend(color_text_list)
 
         if indented_bottom_comment_lines:
@@ -678,7 +706,7 @@ class Protobuf:
         indented_lines = [f'{self.config.ONE_SPACE * indents}{line}' for line in lines]
         string = '\n'.join(indented_lines)
 
-        return string
+        return string, bottom_comment_text_list
 
     def make_indented_line(self, line, indents=0):
         return f'{self.config.ONE_SPACE * indents}{line}'
